@@ -1,5 +1,5 @@
 jomo1ranconhr <-
-  function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, betap=matrix(0,ncol(X),ncol(Y)), up=matrix(0,nrow(unique(clus)),ncol(Z)*ncol(Y)), covp=matrix(diag(1,ncol(Y)),nrow(unique(clus))*ncol(Y),ncol(Y),2), covu=diag(1,ncol(Y)*ncol(Z)), Sp=diag(1,ncol(Y)), Sup=diag(1,ncol(Y)*ncol(Z)), nburn=100, nbetween=100, nimp=5, a=ncol(Y),meth="random", output=1, out.iter=10) {
+  function(Y, X=matrix(1,nrow(Y),1), Z=matrix(1,nrow(Y),1), clus, beta.start=matrix(0,ncol(X),ncol(Y)), u.start=matrix(0,nrow(unique(clus)),ncol(Z)*ncol(Y)), l1cov.start=matrix(diag(1,ncol(Y)),nrow(unique(clus))*ncol(Y),ncol(Y),2), l2cov.start=diag(1,ncol(Y)*ncol(Z)), l1cov.prior=diag(1,ncol(Y)), l2cov.prior=diag(1,ncol(Y)*ncol(Z)), nburn=100, nbetween=100, nimp=5, a=ncol(Y),meth="random", output=1, out.iter=10) {
     clus<-factor(unlist(clus))
     previous_levels_clus<-levels(clus)
     levels(clus)<-0:(nlevels(clus)-1)
@@ -9,22 +9,22 @@ jomo1ranconhr <-
     for (i in 1:ncol(Z)) {
       if (is.factor(Z[,i])) Z[,i]<-as.numeric(Z[,i])
     }
-    stopifnot((meth=="fixed"|meth=="random"),nrow(Y)==nrow(clus),nrow(Y)==nrow(X), nrow(betap)==ncol(X), ncol(betap)==ncol(Y),nrow(covp)==nrow(up)*ncol(covp), nrow(covp)==nrow(up)*ncol(Y), nrow(Sp)==ncol(Sp),nrow(covp)==nrow(up)*nrow(Sp), nrow(Z)==nrow(Y), ncol(covu)==ncol(up), ncol(up)==ncol(Z)*ncol(Y))
-    betait=matrix(0,nrow(betap),ncol(betap))
-    for (i in 1:nrow(betap)) {
-      for (j in 1:ncol(betap)) betait[i,j]=betap[i,j]
+    stopifnot((meth=="fixed"|meth=="random"),nrow(Y)==nrow(clus),nrow(Y)==nrow(X), nrow(beta.start)==ncol(X), ncol(beta.start)==ncol(Y),nrow(l1cov.start)==nrow(u.start)*ncol(l1cov.start), nrow(l1cov.start)==nrow(u.start)*ncol(Y), nrow(l1cov.prior)==ncol(l1cov.prior),nrow(l1cov.start)==nrow(u.start)*nrow(l1cov.prior), nrow(Z)==nrow(Y), ncol(l2cov.start)==ncol(u.start), ncol(u.start)==ncol(Z)*ncol(Y))
+    betait=matrix(0,nrow(beta.start),ncol(beta.start))
+    for (i in 1:nrow(beta.start)) {
+      for (j in 1:ncol(beta.start)) betait[i,j]=beta.start[i,j]
     }
-    covit=matrix(0,nrow(covp),ncol(covp))
-    for (i in 1:nrow(covp)) {
-      for (j in 1:ncol(covp)) covit[i,j]=covp[i,j]
+    covit=matrix(0,nrow(l1cov.start),ncol(l1cov.start))
+    for (i in 1:nrow(l1cov.start)) {
+      for (j in 1:ncol(l1cov.start)) covit[i,j]=l1cov.start[i,j]
     }   
-    uit=matrix(0,nrow(up),ncol(up))
-    for (i in 1:nrow(up)) {
-      for (j in 1:ncol(up)) uit[i,j]=up[i,j]
+    uit=matrix(0,nrow(u.start),ncol(u.start))
+    for (i in 1:nrow(u.start)) {
+      for (j in 1:ncol(u.start)) uit[i,j]=u.start[i,j]
     }
-    covuit=matrix(0,nrow(covu),ncol(covu))
-    for (i in 1:nrow(covu)) {
-      for (j in 1:ncol(covu)) covuit[i,j]=covu[i,j]
+    covuit=matrix(0,nrow(l2cov.start),ncol(l2cov.start))
+    for (i in 1:nrow(l2cov.start)) {
+      for (j in 1:ncol(l2cov.start)) covuit[i,j]=l2cov.start[i,j]
     }   
     ait=0
     ait=a
@@ -52,31 +52,31 @@ jomo1ranconhr <-
     imp[(nrow(clus)+1):(2*nrow(clus)), (ncol(Y)+ncol(X)+ncol(Z)+1)]=clus
     imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+ncol(Z)+2)]=c(1:nrow(Y))
     imp[(nrow(X)+1):(2*nrow(X)), (ncol(Y)+ncol(X)+ncol(Z)+3)]=1
-    betapost<- array(0, dim=c(nrow(betap),ncol(betap),(nimp-1)))
-    bpost<-matrix(0,nrow(betap),ncol(betap))
-    upost<-matrix(0,nrow(up),ncol(up))
-    upostall<-array(0, dim=c(nrow(up),ncol(up),(nimp-1)))
-    omegapost<- array(0, dim=c(nrow(covp),ncol(covp),(nimp-1)))
-    opost<-matrix(0,nrow(covp),ncol(covp))
-    covupost<- array(0, dim=c(nrow(covu),ncol(covu),(nimp-1)))
-    cpost<-matrix(0,nrow(covu),ncol(covu))
+    betapost<- array(0, dim=c(nrow(beta.start),ncol(beta.start),(nimp-1)))
+    bpost<-matrix(0,nrow(beta.start),ncol(beta.start))
+    upost<-matrix(0,nrow(u.start),ncol(u.start))
+    upostall<-array(0, dim=c(nrow(u.start),ncol(u.start),(nimp-1)))
+    omegapost<- array(0, dim=c(nrow(l1cov.start),ncol(l1cov.start),(nimp-1)))
+    opost<-matrix(0,nrow(l1cov.start),ncol(l1cov.start))
+    covupost<- array(0, dim=c(nrow(l2cov.start),ncol(l2cov.start),(nimp-1)))
+    cpost<-matrix(0,nrow(l2cov.start),ncol(l2cov.start))
     meanobs<-colMeans(Y,na.rm=TRUE)
     for (i in 1:nrow(Y)) for (j in 1:ncol(Y)) if (is.na(Yimp[i,j])) Yimp[i,j]=meanobs[j]
     #for (i in 1:nrow(Y)) for (j in 1:ncol(Y)) if (is.na(Yimp[i,j])) Yimp[i,j]=rnorm(1,mean=meanobs[j], sd=0.01)
     if (meth=="fixed") {
-      .Call("jomo1ranconhf", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit,opost, covuit,cpost, nburn, Sp, Sup,out.iter, PACKAGE = "jomo") 
+      .Call("jomo1ranconhf", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit,opost, covuit,cpost, nburn, l1cov.prior, l2cov.prior,out.iter, PACKAGE = "jomo") 
     }
     if (meth=="random") {
-      .Call("jomo1ranconhr", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit,opost, covuit,cpost, nburn, Sp, Sup, ait,out.iter, PACKAGE = "jomo") 
+      .Call("jomo1ranconhr", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit,opost, covuit,cpost, nburn, l1cov.prior, l2cov.prior, ait,out.iter, PACKAGE = "jomo") 
     }
     #betapost[,,1]=bpost
     #upostall[,,1]=upost
     #omegapost[,,(1)]=opost
     #covupost[,,(1)]=cpost
-    bpost<-matrix(0,nrow(betap),ncol(betap))
-    opost<-matrix(0,nrow(covp),ncol(covp))
-    upost<-matrix(0,nrow(up),ncol(up))
-    cpost<-matrix(0,nrow(covu),ncol(covu))
+    bpost<-matrix(0,nrow(beta.start),ncol(beta.start))
+    opost<-matrix(0,nrow(l1cov.start),ncol(l1cov.start))
+    upost<-matrix(0,nrow(u.start),ncol(u.start))
+    cpost<-matrix(0,nrow(l2cov.start),ncol(l2cov.start))
     imp[(nrow(Y)+1):(2*nrow(Y)),1:ncol(Y)]=Yimp2
     Yimp=Yimp2
     if (output==1) cat("First imputation registered.", "\n")
@@ -88,19 +88,19 @@ jomo1ranconhr <-
       imp[(i*nrow(Z)+1):((i+1)*nrow(Z)), (ncol(Y)+ncol(X)+ncol(Z)+2)]=c(1:nrow(Y))
       imp[(i*nrow(Z)+1):((i+1)*nrow(Z)), (ncol(Y)+ncol(X)+ncol(Z)+3)]=i
       if (meth=="fixed") {
-        .Call("jomo1ranconhf", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit, opost, covuit, cpost, nbetween, Sp, Sup,out.iter, PACKAGE = "jomo") 
+        .Call("jomo1ranconhf", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit, opost, covuit, cpost, nbetween, l1cov.prior, l2cov.prior,out.iter, PACKAGE = "jomo") 
       }
       if (meth=="random") {
-        .Call("jomo1ranconhr", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit, opost, covuit, cpost, nbetween, Sp, Sup, ait,out.iter, PACKAGE = "jomo")   
+        .Call("jomo1ranconhr", Y, Yimp, Yimp2, X, Z, clus, betait, uit, bpost, upost, covit, opost, covuit, cpost, nbetween, l1cov.prior, l2cov.prior, ait,out.iter, PACKAGE = "jomo")   
       }
       betapost[,,(i-1)]=bpost
       upostall[,,(i-1)]=upost
       omegapost[,,(i-1)]=opost
       covupost[,,(i-1)]=cpost
-      bpost<-matrix(0,nrow(betap),ncol(betap))
-      opost<-matrix(0,nrow(covp),ncol(covp))
-      upost<-matrix(0,nrow(up),ncol(up))
-      cpost<-matrix(0,nrow(covu),ncol(covu))
+      bpost<-matrix(0,nrow(beta.start),ncol(beta.start))
+      opost<-matrix(0,nrow(l1cov.start),ncol(l1cov.start))
+      upost<-matrix(0,nrow(u.start),ncol(u.start))
+      cpost<-matrix(0,nrow(l2cov.start),ncol(l2cov.start))
       imp[(i*nrow(Y)+1):((i+1)*nrow(Y)),1:ncol(Y)]=Yimp2
       Yimp=Yimp2
       if (output==1) cat("Imputation number ", i, "registered", "\n")
@@ -122,6 +122,9 @@ jomo1ranconhr <-
     imp<-data.frame(imp)
     levels(imp[,(ncol(Y)+ncol(X)+ncol(Z)+1)])<-previous_levels_clus
     levels(clus)<-previous_levels_clus
+    for (j in 1:(ncol(Y)+ncol(X)+ncol(Z))) {
+      imp[,j]=as.numeric(imp[,j])
+    }
     if (is.null(colnamy)) colnamy=paste("Y", 1:ncol(Y), sep = "")
     if (is.null(colnamz)) colnamz=paste("Z", 1:ncol(Z), sep = "")
     if (is.null(colnamx)) colnamx=paste("X", 1:ncol(X), sep = "")
