@@ -203,7 +203,7 @@ for (i=0;i<ns;i++) {
 	for (jj=1;jj<JX*JY;jj++) for (tt=0;tt<jj;tt++) invomega2[jj+JX*JY*tt]=invomega2[tt+JX*JY*jj];
 	r8mat_mm_new(JY*JX,JY*JX,1,invomega2,sumxy,mu);
 	r8mat_pofac(JY * JX,invomega2,help3,4);
-	r8vec_multinormal_sample(JY*JX, mu,help3, REAL(beta),newbeta,fl);
+	r8vec_multinormal_sample(JY*JX, mu,help3, REAL(beta),newbeta,0);
 	r8mat_add(Ib,Jb,REAL(beta),REAL(betapost));
 	for (c=0;c<nj;c++) {
 		for (j=0;j<JY;j++) {
@@ -243,7 +243,7 @@ for (i=0;i<ns;i++) {
 		for (jj=1;jj<JZ*JY;jj++) for (tt=0;tt<jj;tt++) invomega3[jj+JZ*JY*tt]=invomega3[tt+JZ*JY*jj];
 		r8mat_mm_new(JY*JZ,JY*JZ,1,invomega3,sumzy,mu2);
 		r8mat_pofac(JY * JZ,invomega3,help5,7); 
-		r8vec_multinormal_sample(JY*JZ, mu2,help5,newu, incrzy,fl);
+		r8vec_multinormal_sample(JY*JZ, mu2,help5,newu, incrzy,0);
 		for (t=0;t<JY;t++) for (k=0;k<JZ;k++) REAL(u)[c+nj*(k+t*JZ)] = newu[k+t*JZ];
 		
 	}
@@ -261,7 +261,7 @@ for (i=0;i<ns;i++) {
 	r8mat_pofac(JY*JZ,mu3,help5,8);
 	r8mat_poinv(JY*JZ, help5, invomega3);
 	for (jj=1;jj<(JY*JZ);jj++) for (tt=0;tt<jj;tt++) invomega3[jj+(JZ*JY)*tt]=invomega3[tt+(JZ*JY)*jj];
-	wishart_sample(JY*JZ,(nj+JY*JZ),invomega3,newomega, help5,sumzi,incrzz,mu3,fl);
+	wishart_sample(JY*JZ,(nj+JY*JZ),invomega3,newomega, help5,sumzi,incrzz,mu3,0);
 	r8mat_pofac(JY * JZ,newomega, help5,9);
 	r8mat_poinv(JY * JZ, help5,invomega3);
 	for (jj=1;jj<(JY*JZ);jj++) for (tt=0;tt<jj;tt++) invomega3[jj+(JZ*JY)*tt]=invomega3[tt+(JZ*JY)*jj];
@@ -283,13 +283,13 @@ for (i=0;i<ns;i++) {
 	r8mat_poinv(JY, help7, Gammastar);
 	for (jj=1;jj<JY;jj++) for (tt=0;tt<jj;tt++) Gammastar[jj+JY*tt]=Gammastar[tt+JY*jj];
 
-	wishart_sample(JY,(nj*a+gamma),Gammastar,invA,help, omegaoo,omegaom,omegamm,fl);
+	wishart_sample(JY,(nj*a+gamma),Gammastar,invA,help, omegaoo,omegaom,omegamm,0);
 	u_m=newton_raphson(u_new,precision, dx,eta,JY,nj,allinvomega,invomega,invA,help,help2);
 	if (u_m!=-9999) {
 		con=-log_f_u(eta, u_m, JY, nj, allinvomega, invomega,  invA,  help,  help2);
 		deriv2=derive2_f_u(dx,eta, u_m, JY, nj, allinvomega, invomega,  invA,  help,  help2,con);
 		lambda=sqrt(-5/(4*deriv2));
-		u_prop=lambda*t_sample(4,fl)+u_m;
+		u_prop=lambda*t_sample(4,0)+u_m;
 		con2=exp(log_f_u(eta, u_prop, JY, nj, allinvomega, invomega, invA,help,help2)-log_f_u(eta, u_new, JY, nj, allinvomega, invomega, invA,help,help2))*h_u(u_new,u_m,lambda)/h_u(u_prop,u_m,lambda);
 		if ((( double ) unif_rand ( ) )<r8_min(1,con2)) u_new=u_prop;
 		a=u_new;
@@ -299,7 +299,7 @@ for (i=0;i<ns;i++) {
 		con=-log_f_u(eta, u_m, JY, nj, allinvomega, invomega,  invA,  help,  help2);
 		deriv2=derive2_log_f_u(dx,eta, u_m, JY, nj, allinvomega, invomega,  invA,  help,  help2);
 		lambda=sqrt(-5/(4*deriv2));
-		u_prop=lambda*t_sample(4,fl)+u_m;
+		u_prop=lambda*t_sample(4,0)+u_m;
 		con2=exp(log_f_u(eta, u_prop, JY, nj, allinvomega, invomega, invA,help,help2)-log_f_u(eta, u_new, JY, nj, allinvomega, invomega, invA,help,help2))*h_u(u_new,u_m,lambda)/h_u(u_prop,u_m,lambda);
 		if ((( double ) unif_rand ( ) )<r8_min(1,con2)) u_new=u_prop;
 		a=u_new;
@@ -337,7 +337,7 @@ for (i=0;i<ns;i++) {
 		r8mat_pofac(JY,mu4,help,11);
 		r8mat_poinv(JY, help,invomega);
 		for (jj=1;jj<JY;jj++) for (tt=0;tt<jj;tt++) invomega[jj+JY*tt]=invomega[tt+JY*jj];
-		wishart_sample(JY,clusnum[c]+a,invomega,newomega2,help, omegaoo,omegaom,omegamm,fl);
+		wishart_sample(JY,clusnum[c]+a,invomega,newomega2,help, omegaoo,omegaom,omegamm,0);
 		r8mat_pofac(JY,newomega2,help,12);
 		r8mat_poinv(JY, help,invomega);
 		for (jj=1;jj<JY;jj++) for (tt=0;tt<jj;tt++) invomega[jj+JY*tt]=invomega[tt+JY*jj];
@@ -406,7 +406,7 @@ for (i=0;i<ns;i++) {
 			r8mat_divide(nmiss,nmiss,-1,omegadrawmiss);
 			r8mat_add(nmiss,nmiss,omegamm,omegadrawmiss);
 			r8mat_pofac(nmiss,omegadrawmiss,help9,14);
-			r8vec_multinormal_sample(nmiss,mumiss,help9,Ymiss,help6,fl);
+			r8vec_multinormal_sample(nmiss,mumiss,help9,Ymiss,help6,0);
 			countm=0;
 			for (k=0;k<JY;k++) {
 				if (ISNAN(REAL(Y)[j+k*IY])) {
@@ -426,7 +426,7 @@ for (i=0;i<ns;i++) {
 	
 	}
 
-if ((i+1)%10==0) Rprintf("Iteration %d completed\n",i+1);
+if ((i+1)%fl==0) Rprintf("Iteration %d completed\n",i+1);
 }
 for(i=0;i<IY;i++)  {
 	for(j=0;j<JY;j++)  {
